dijit/layout/BorderContainer Nested Test

## dijit/layout/BorderContainer Nested tests

The second tab holds a single BorderContainer but specifying layoutPriority on it's children to have multiple children for each region.

The first tab holds a BorderContainer which nests another BorderContainer, simulating multiple children in a single region.

left
right
top bar
bottom bar
left inner
right inner
inner top bar
inner bottom bar
main panel with a link.
(to check we're copying children around properly).
Here's some text that comes AFTER the combo box.
top bar (layoutPriority == 1)
second top bar (layoutPriority == 2)
left (layoutPriority == 3)
inner left (layoutPriority == 4)
inner top bar (layoutPriority == 5)
center
inner bottom bar (layoutPriority == 5)
inner right (layoutPriority == 4)
right (layoutPriority == 3)
second bottom bar (layoutPriority == 2)
bottom bar (layoutPriority == 1)